==> GeoFIS_1.0.1.tar.gz: GeoFIS/src/rcpp/vector_equal_to.hpp <==
/**
 * GeoFIS R package
 *
 * Copyright (C) 2021 INRAE
 *
 * Authors:
 * 	Jean-luc Lablée - INRAE
 * 	Serge Guillaume - INRAE
 *
 * License: CeCILL v2.1
 * 	https://cecill.info/licences/Licence_CeCILL_V2.1-en.html
 * 	https://cecill.info/licences/Licence_CeCILL_V2.1-fr.html
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "https://cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights, and the successive licensors have only limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#ifndef H00683A8E_F8D5_4819_B75B_0436E68C661B
#define H00683A8E_F8D5_4819_B75B_0436E68C661B

#include <Rcpp.h>
#include <functional>

namespace std {

template <int RTYPE> struct equal_to<Rcpp::Vector<RTYPE> > : public binary_function<Rcpp::Vector<RTYPE>, Rcpp::Vector<RTYPE>, bool> {

	inline bool operator() (const Rcpp::Vector<RTYPE> &lhs, const Rcpp::Vector<RTYPE> &rhs) const {
		// Rcpp sugar Vector operator== is in global namespace
		return Rcpp::is_true(Rcpp::all(::operator==(lhs, rhs)));
	}
};

} // namespace std

#endif // H00683A8E_F8D5_4819_B75B_0436E68C661B

==> GeoFIS_1.0.3.tar.gz: GeoFIS/src/rcpp/vector_equal_to.hpp <==
/**
 * GeoFIS R package
 *
 * Copyright (C) 2021 INRAE
 *
 * Authors:
 * 	Jean-luc Lablée - INRAE
 * 	Serge Guillaume - INRAE
 *
 * License: CeCILL v2.1
 * 	https://cecill.info/licences/Licence_CeCILL_V2.1-en.html
 * 	https://cecill.info/licences/Licence_CeCILL_V2.1-fr.html
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "https://cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights, and the successive licensors have only limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#ifndef H00683A8E_F8D5_4819_B75B_0436E68C661B
#define H00683A8E_F8D5_4819_B75B_0436E68C661B

#include <Rcpp.h>

namespace std {

template <int RTYPE> struct equal_to<Rcpp::Vector<RTYPE> > {

	inline bool operator() (const Rcpp::Vector<RTYPE> &lhs, const Rcpp::Vector<RTYPE> &rhs) const {
		// Rcpp sugar Vector operator== is in global namespace
		return Rcpp::is_true(Rcpp::all(::operator==(lhs, rhs)));
	}
};

} // namespace std

#endif // H00683A8E_F8D5_4819_B75B_0436E68C661B
